@@ -28,6 +28,8 @@
 
 #include "cliplugin.h"
 #include "pluginmanager.h"
+#include "autotests/testhelper/testhelper.h"
+#include "kerfuffle/jobs.h"
 
 using namespace Kerfuffle;
 
@@ -53,6 +55,4 @@ private:
     Plugin *m_plugin;
 };
 
-Q_DECLARE_METATYPE(ArchiveEntry)
-
 #endif
