@@ -27,8 +27,9 @@
  */
 
 #include "addtoarchive.h"
-#include "ark_debug.h"
+#include "archiveentry.h"
 #include "archive_kerfuffle.h"
+#include "ark_debug.h"
 #include "createdialog.h"
 #include "jobs.h"
 
@@ -38,7 +39,6 @@
 #include <KLocalizedString>
 #include <kio/job.h>
 
-#include <QDebug>
 #include <QFileInfo>
 #include <QDir>
 #include <QMimeDatabase>
@@ -48,7 +48,9 @@
 namespace Kerfuffle
 {
 AddToArchive::AddToArchive(QObject *parent)
-        : KJob(parent), m_changeToFirstPath(false)
+        : KJob(parent)
+        , m_changeToFirstPath(false)
+        , m_enableHeaderEncryption(false)
 {
 }
 
@@ -113,7 +115,9 @@ bool AddToArchive::showAddDialog()
 
 bool AddToArchive::addInput(const QUrl &url)
 {
-    m_inputs << url.toLocalFile();
+    Archive::Entry *entry = new Archive::Entry(this);
+    entry->setFullPath(url.toLocalFile());
+    m_entries << entry;
 
     if (m_firstPath.isEmpty()) {
         QString firstEntry = url.toLocalFile();
@@ -132,19 +136,13 @@ void AddToArchive::start()
 
 void AddToArchive::slotStartJob()
 {
-    Kerfuffle::CompressionOptions options;
-
-    if (m_inputs.isEmpty()) {
+    if (m_entries.isEmpty()) {
         KMessageBox::error(NULL, i18n("No input files were given."));
         emitResult();
         return;
     }
 
-    Kerfuffle::Archive *archive;
-    if (!m_filename.isEmpty()) {
-        archive = Kerfuffle::Archive::create(m_filename, m_mimeType, this);
-        qCDebug(ARK) << "Set filename to " << m_filename;
-    } else {
+    if (m_filename.isEmpty()) {
         if (m_autoFilenameSuffix.isEmpty()) {
             KMessageBox::error(Q_NULLPTR, xi18n("You need to either supply a filename for the archive or a suffix (such as rar, tar.gz) with the <command>--autofilename</command> argument."));
             emitResult();
@@ -157,7 +155,7 @@ void AddToArchive::slotStartJob()
             return;
         }
 
-        const QString base = detectBaseName(m_inputs);
+        const QString base = detectBaseName(m_entries);
 
         QString finalName = base + QLatin1Char( '.' ) + m_autoFilenameSuffix;
 
@@ -169,32 +167,11 @@ void AddToArchive::slotStartJob()
             finalName = base + QLatin1Char( '_' ) + QString::number(appendNumber) + QLatin1Char( '.' ) + m_autoFilenameSuffix;
         }
 
-        qCDebug(ARK) << "Autoset filename to "<< finalName;
-        archive = Kerfuffle::Archive::create(finalName, m_mimeType, this);
+        qCDebug(ARK) << "Autoset filename to" << finalName;
+        m_filename = finalName;
     }
 
-    Q_ASSERT(archive);
-
-    if (!archive->isValid()) {
-        if (archive->error() == NoPlugin) {
-            KMessageBox::error(Q_NULLPTR, i18n("Failed to create the new archive. No suitable plugin found."));
-            emitResult();
-            return;
-        }
-        if (archive->error() == FailedPlugin) {
-            KMessageBox::error(Q_NULLPTR, i18n("Failed to create the new archive. Could not load a suitable plugin."));
-            emitResult();
-            return;
-        }
-    } else if (archive->isReadOnly()) {
-        KMessageBox::error(Q_NULLPTR, i18n("It is not possible to create archives of this type."));
-        emitResult();
-        return;
-    }
-
-    if (!m_password.isEmpty()) {
-        archive->encrypt(m_password, m_enableHeaderEncryption);
-    }
+    Kerfuffle::CompressionOptions options;
 
     if (m_changeToFirstPath) {
         if (m_firstPath.isEmpty()) {
@@ -205,43 +182,43 @@ void AddToArchive::slotStartJob()
 
         const QDir stripDir(m_firstPath);
 
-        for (int i = 0; i < m_inputs.size(); ++i) {
-            m_inputs[i] = stripDir.absoluteFilePath(m_inputs.at(i));
+        foreach (Archive::Entry *entry, m_entries) {
+            entry->setFullPath(stripDir.absoluteFilePath(entry->fullPath()));
         }
 
-
-        options[QStringLiteral( "GlobalWorkDir" )] = stripDir.path();
         qCDebug(ARK) << "Setting GlobalWorkDir to " << stripDir.path();
+        options.setGlobalWorkDir(stripDir.path());
     }
 
-    Kerfuffle::AddJob *job =
-        archive->addFiles(m_inputs, options);
+    auto createJob = Archive::create(m_filename, m_mimeType, m_entries, options, this);
 
-    KIO::getJobTracker()->registerJob(job);
+    if (!m_password.isEmpty()) {
+        createJob->enableEncryption(m_password, m_enableHeaderEncryption);
+    }
 
-    connect(job, &Kerfuffle::AddJob::result, this, &AddToArchive::slotFinished);
-
-    job->start();
+    KIO::getJobTracker()->registerJob(createJob);
+    connect(createJob, &KJob::result, this, &AddToArchive::slotFinished);
+    createJob->start();
 }
 
 void AddToArchive::slotFinished(KJob *job)
 {
     qCDebug(ARK) << "AddToArchive job finished";
 
-    if (job->error() && !job->errorText().isEmpty()) {
-        KMessageBox::error(Q_NULLPTR, job->errorText());
+    if (job->error() && !job->errorString().isEmpty()) {
+        KMessageBox::error(Q_NULLPTR, job->errorString());
     }
 
     emitResult();
 }
 
-QString AddToArchive::detectBaseName(const QStringList &paths) const
+QString AddToArchive::detectBaseName(const QVector<Archive::Entry*> &entries) const
 {
-    QFileInfo fileInfo = QFileInfo(paths.first());
+    QFileInfo fileInfo = QFileInfo(entries.first()->fullPath());
     QDir parentDir = fileInfo.dir();
     QString base = parentDir.absolutePath() + QLatin1Char('/');
 
-    if (paths.size() > 1) {
+    if (entries.size() > 1) {
         if (!parentDir.isRoot()) {
             // Use directory name for the new archive.
             base += parentDir.dirName();
