@@ -281,6 +281,12 @@ void Part::extractSelectedFilesTo(const QString& localPath)
     job->start();
 }
 
+void Part::guiActivateEvent(KParts::GUIActivateEvent *event)
+{
+    // #357660: prevent parent's implementation from changing the window title.
+    Q_UNUSED(event)
+}
+
 void Part::setupView()
 {
     m_view->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -796,7 +802,7 @@ bool Part::confirmAndDelete(const QString &targetFile)
                                                              "The archive <filename>%1</filename> already exists. Do you wish to overwrite it?",
                                                              targetInfo.fileName()),
                                                       i18nc("@title:window", "File Exists"),
-                                                      KGuiItem(i18nc("@action:button", "Overwrite")),
+                                                      KStandardGuiItem::overwrite(),
                                                       KStandardGuiItem::cancel());
 
     if (buttonCode != KMessageBox::Yes || !targetInfo.isWritable()) {
