@@ -277,7 +277,8 @@ bool CliPlugin::setMovingAddedFiles()
 
     // We have to exclude file name from destination path in order to pass it to addFiles method.
     const QString destinationPath = m_passedDestination->fullPath();
-    if (!destinationPath.endsWith(QLatin1Char('/')) || destinationPath.count(QLatin1Char('/')) > 1) {
+    const int slashCount = destinationPath.count(QLatin1Char('/'));
+    if (slashCount > 1 || (slashCount == 1 && !destinationPath.endsWith(QLatin1Char('/')))) {
         int destinationLength = destinationPath.count();
         bool iteratedChar = false;
         do {
@@ -287,8 +288,8 @@ bool CliPlugin::setMovingAddedFiles()
             }
         } while (destinationLength > 0 && !(iteratedChar && destinationPath.at(destinationLength) == QLatin1Char('/')));
         m_passedDestination->setProperty("fullPath", destinationPath.left(destinationLength + 1));
-   } else {
-        // ...unless the destination path is already a single folder, e.g. "dir/".
+    } else {
+        // ...unless the destination path is already a single folder, e.g. "dir/", or a file, e.g. "foo.txt".
         // In this case we're going to add to the root, so we just need to set a null destination.
         m_passedDestination = Q_NULLPTR;
     }
@@ -310,8 +311,16 @@ QString CliPlugin::convertCompressionMethod(const QString &method)
         return QStringLiteral("Store");
     } else if (method.startsWith(QLatin1String("def"))) {
         return QStringLiteral("Deflate");
+    } else if (method == QLatin1String("d64N")) {
+        return QStringLiteral("Deflate64");
     } else if (method == QLatin1String("bzp2")) {
         return QStringLiteral("BZip2");
+    } else if (method == QLatin1String("lzma")) {
+        return QStringLiteral("LZMA");
+    } else if (method == QLatin1String("ppmd")) {
+        return QStringLiteral("PPMd");
+    } else if (method == QLatin1String("u095")) {
+        return QStringLiteral("XZ");
     } else if (method == QLatin1String("u099")) {
         emit encryptionMethodFound(QStringLiteral("AES"));
         return i18nc("referred to compression method", "unknown");
